##  SAP BTP Meta Model Extension
SAP BTP extends the meta model by adding the microservice and business application fact sheet subtypes to your meta model, preparing your workspace for discovery of BTP extensions. The meta model extension includes the following:
  * The microservice fact sheet subtype to capture microservices as an application subtype.
  * A relation between microservice and business application fact sheet subtypes to indicate which business applications use a specific microservice.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
